@@ -278,7 +278,18 @@ def build_enums(schema: graphql.GraphQLSchema) -> str:
     return _build_enums(filter_schema(schema, graphql.GraphQLEnumType))
 
 
-def _build_inputs(input_types_d: T.Dict[str, graphql.GraphQLInputObjectType]) -> str:
+def to_pydantic_line(input_name: str) -> str:
+    s = f"""
+def to_pydantic(self) -> {input_name}:
+    return {input_name}.parse_raw(json.dumps(self, cls=EnhancedJSONEncoder))
+    """
+    return s
+
+
+def _build_inputs(
+    input_types_d: T.Dict[str, graphql.GraphQLInputObjectType],
+    for_strawberry: bool = False,
+) -> str:
     type_str_lst: T.List[str] = []
     for type_name, object_type in input_types_d.items():
         field_str_lst: T.List[str] = []
@@ -286,17 +297,28 @@ def _build_inputs(input_types_d: T.Dict[str, graphql.GraphQLInputObjectType]) ->
             python_line = python_line_from_gql_field(
                 field_name=field_name, gql_field=gql_field
             )
+            if for_strawberry:
+                ending = "" if "..." in python_line else " = None"
+                python_line = f'{python_line[:python_line.index(" =")]}{ending}'
             field_str_lst.append(python_line)
         fields_str = "\n".join(field_str_lst)
-        type_str = f"class {type_name}({ORM_MODEL_NAME}):\n{indent_lines(fields_str)}"
+        class_str = f"class {type_name}({ORM_MODEL_NAME}):"
+        if for_strawberry:
+            class_str = f"@strawberry.input\nclass {type_name}:"
+        type_str = f"{class_str}\n{indent_lines(fields_str)}"
+        if for_strawberry:
+            type_str += f"\n{indent_lines(to_pydantic_line(input_name=type_name))}"
         type_str_lst.append(type_str)
     types_str = "\n".join(type_str_lst)
     s = format_str(types_str, mode=FileMode())
     return s
 
 
-def build_inputs(schema: graphql.GraphQLSchema) -> str:
-    return _build_inputs(filter_schema(schema, graphql.GraphQLInputObjectType))
+def build_inputs(schema: graphql.GraphQLSchema, for_strawberry: bool = False) -> str:
+    return _build_inputs(
+        filter_schema(schema, graphql.GraphQLInputObjectType),
+        for_strawberry=for_strawberry,
+    )
 
 
 def _build_non_input_non_nodes(
@@ -682,7 +704,43 @@ def get_class_names_from_str(s: str) -> T.List[str]:
     return re.findall(class_names_pattern, s)
 
 
-def build_all(schema: graphql.GraphQLSchema, node_configs: T.List[NodeConfig]) -> str:
+def build_strawberry_class(schema: graphql.GraphQLSchema) -> str:
+    pre = """
+import dataclasses
+import json
+import strawberry
+
+class EnhancedJSONEncoder(json.JSONEncoder):
+    def default(self, o):
+        if dataclasses.is_dataclass(o):
+            return dataclasses.asdict(o)
+        return super().default(o)
+    """
+
+    enum_names: T.List[str] = []
+    for type_name, gql_type in schema.type_map.items():
+        if isinstance(gql_type, graphql.GraphQLEnumType):
+            if not type_name.startswith("__"):
+                enum_names.append(type_name)
+    enums_str = "\n".join([f"strawberry.enum({name})" for name in enum_names])
+
+    inputs_s = build_inputs(schema=schema, for_strawberry=True)
+    lines = [
+        pre,
+        f"class Strawberry:",
+        indent_lines(enums_str),
+        indent_lines(inputs_s),
+    ]
+    s = "\n".join(lines)
+    s = format_str(s, mode=FileMode())
+    return s
+
+
+def build_all(
+    schema: graphql.GraphQLSchema,
+    node_configs: T.List[NodeConfig],
+    include_strawberry: bool = False,
+) -> str:
     # order map so that you can track db schema changes
     schema.type_map = {
         k: schema.type_map[k] for k in sorted(list(schema.type_map.keys()))
@@ -727,6 +785,10 @@ def build_all(schema: graphql.GraphQLSchema, node_configs: T.List[NodeConfig]) -
     ]
     final_s = "\n".join(lines)
     s = format_str(final_s, mode=FileMode())
+    if include_strawberry:
+        straw_str = build_strawberry_class(schema=schema)
+        s += f"\n{straw_str}"
+        s = format_str(s, mode=FileMode())
     return s
 
 
@@ -772,21 +834,30 @@ def filename_safe(s: str) -> str:
     return "".join([c for c in s if c.isalpha() or c.isdigit() or c == " "]).rstrip()
 
 
-def build_from_app_config(app_name: str, app_config: dict, parent_dir: Path) -> None:
+def build_from_app_config(
+    app_name: str, app_config: dict, parent_dir: Path, include_strawberry: bool = False
+) -> None:
     node_configs = node_configs_from_app_config(
         app_name=app_name, app_config=app_config
     )
     schema = schema_from_url(app_config["url"])
-    s = build_all(schema=schema, node_configs=node_configs)
+    s = build_all(
+        schema=schema, node_configs=node_configs, include_strawberry=include_strawberry
+    )
     open(parent_dir / f"{filename_safe(app_name)}.py", "w").write(s)
 
 
-def build_from_config(config_path: Path, path_to_write_to: Path) -> None:
+def build_from_config(
+    config_path: Path, path_to_write_to: Path, include_strawberry: bool = False
+) -> None:
     path_to_write_to.mkdir(parents=True, exist_ok=True)
     config = json.loads(open(config_path, "r").read())
     for app_name, app_config in config.items():
         build_from_app_config(
-            app_name=app_name, app_config=app_config, parent_dir=path_to_write_to
+            app_name=app_name,
+            app_config=app_config,
+            parent_dir=path_to_write_to,
+            include_strawberry=include_strawberry,
         )
 
 
