@@ -2,7 +2,7 @@ import typing as T
 from enum import Enum
 from pydantic import BaseModel
 from fastapi.encoders import jsonable_encoder
-from .gql import GQLException
+from dgraph_orm import GQLException
 
 
 class GQLInput(BaseModel):
